@@ -202,14 +202,13 @@ class Model:
         self.__styles = []
         for row in self.__worksheet.iter_rows(min_row=1, max_col=self.__columns, max_row=self.__rows):
             for cell in row:
-                s = cell.coordinate
                 if cell.value != None:
                     value = str(cell.value)
                     if value[0]=='$':
                         self.__variables.append(Variable(value[1:len(value)], cell.row, cell.column, None))
                     else:
                         self.__variables.append(Variable('Constanta', cell.row, cell.column, cell.value))
-                self.__styles.append(Style(cell.row, cell.column, cell.data_type, cell.font, cell.alignment, cell.fill, cell.border))
+                self.__styles.append(Style(cell.coordinate, cell.row, cell.column, cell.data_type, cell.font, cell.alignment, cell.fill, cell.border))
 
         self.__columns_width = []
         for row in self.__worksheet.iter_rows(min_row=1, max_col=self.__columns, max_row=1):
